@@ -48,12 +48,9 @@ void KDFTopLevel::closeEvent(QCloseEvent *event)
 int main(int argc, char **argv)
 {
     //Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
 
-    KLocalizedString::setApplicationDomain("kdf");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kdf"));
 
     KAboutData aboutData(QStringLiteral("kdf"),
                          i18n("KDiskFree"),
@@ -103,3 +100,5 @@ int main(int argc, char **argv)
 }
 
 
+
+#include "moc_kdf.cpp"
